@@ -4,9 +4,12 @@ from collections import namedtuple
 
 import numpy as np
 
+# OSEF imports
 import osef._unpackers as _unpackers
 import osef._packers as _packers
-from osef.constants import OsefTypes
+from osef.osef_types import OsefTypes
+from osef.osef_types import OsefKeys
+
 
 LeafInfo = namedtuple("Leaf", "unpack_function pack_function")
 InternalNodeInfo = namedtuple("InternalNode", "type")
@@ -15,16 +18,16 @@ TypeInfo = namedtuple("Type", "name node_info")
 
 outsight_types = {
     OsefTypes.AUGMENTED_CLOUD.value: TypeInfo(
-        "augmented_cloud", InternalNodeInfo(dict)
+        OsefKeys.AUGMENTED_CLOUD.value, InternalNodeInfo(dict)
     ),
-    OsefTypes.NUMBER_POINTS.value: TypeInfo(
-        "number_of_points",
+    OsefTypes.NUMBER_OF_POINTS.value: TypeInfo(
+        OsefKeys.NUMBER_OF_POINTS.value,
         LeafInfo(
             _unpackers._get_value_unpacker("<L"), _packers._get_value_packer("<L")
         ),
     ),
-    OsefTypes.SPHERICAL_COORD_3F.value: TypeInfo(
-        "spherical_coordinates",
+    OsefTypes.SPHERICAL_COORDINATES.value: TypeInfo(
+        OsefKeys.SPHERICAL_COORDINATES.value,
         LeafInfo(
             _unpackers._get_structured_array_unpacker(
                 np.dtype(
@@ -41,19 +44,19 @@ outsight_types = {
         ),
     ),
     OsefTypes.REFLECTIVITIES.value: TypeInfo(
-        "reflectivities",
+        OsefKeys.REFLECTIVITIES.value,
         LeafInfo(
             _unpackers._get_array_unpacker(np.dtype(np.uint8)), _packers._array_packer
         ),
     ),
-    OsefTypes.BACKGROUND_FLAG.value: TypeInfo(
-        "background_flags",
+    OsefTypes.BACKGROUND_FLAGS.value: TypeInfo(
+        OsefKeys.BACKGROUND_FLAGS.value,
         LeafInfo(
             _unpackers._get_array_unpacker(np.dtype(bool)), _packers._array_packer
         ),
     ),
-    OsefTypes.CARTESIAN_COORD_3F.value: TypeInfo(
-        "cartesian_coordinates",
+    OsefTypes.CARTESIAN_COORDINATES.value: TypeInfo(
+        OsefKeys.CARTESIAN_COORDINATES.value,
         LeafInfo(
             _unpackers._get_structured_array_unpacker(
                 np.dtype(
@@ -63,51 +66,54 @@ outsight_types = {
             _packers._structured_array_packer,
         ),
     ),
-    OsefTypes.BGR_COLOR.value: TypeInfo(
-        "bgr_colors", LeafInfo(_unpackers._bytes_unpacker, _packers._bytes_packer)
+    OsefTypes._BGR_COLORS.value: TypeInfo(
+        OsefKeys._BGR_COLORS.value,
+        LeafInfo(_unpackers._bytes_unpacker, _packers._bytes_packer),
     ),
-    OsefTypes.OBJECT_DETECTION_FRAME.value: TypeInfo(
-        "object_detection_frame", InternalNodeInfo(dict)
+    OsefTypes._OBJECT_DETECTION_FRAME.value: TypeInfo(
+        OsefKeys._OBJECT_DETECTION_FRAME.value, InternalNodeInfo(dict)
     ),
-    OsefTypes.IMAGE_DIM.value: TypeInfo(
-        "image_dimension",
+    OsefTypes._IMAGE_DIMENSION.value: TypeInfo(
+        OsefKeys._IMAGE_DIMENSION.value,
         LeafInfo(
             _unpackers._get_dict_unpacker("<LL", ["image_width", "image_height"]),
             _packers._get_dict_packer("<LL", ["image_width", "image_height"]),
         ),
     ),
-    OsefTypes.NUMBER_OBJECT.value: TypeInfo(
-        "number_of_objects",
+    OsefTypes.NUMBER_OF_OBJECTS.value: TypeInfo(
+        OsefKeys.NUMBER_OF_OBJECTS.value,
         LeafInfo(
             _unpackers._get_value_unpacker("<L"), _packers._get_value_packer("<L")
         ),
     ),
-    OsefTypes.CLOUD_FRAME.value: TypeInfo("cloud_frame", InternalNodeInfo(dict)),
+    OsefTypes._CLOUD_FRAME.value: TypeInfo(
+        OsefKeys._CLOUD_FRAME.value, InternalNodeInfo(dict)
+    ),
     OsefTypes.TIMESTAMP_MICROSECOND.value: TypeInfo(
-        "timestamp_microsecond",
+        OsefKeys.TIMESTAMP_MICROSECOND.value,
         LeafInfo(_unpackers._parse_timestamp, _packers._timestamp_packer),
     ),
-    OsefTypes.AZIMUTHS_COL.value: TypeInfo(
-        "azimuths_column",
+    OsefTypes._AZIMUTHS_COLUMN.value: TypeInfo(
+        OsefKeys._AZIMUTHS_COLUMN.value,
         LeafInfo(
             _unpackers._get_array_unpacker(np.dtype(np.float32)), _packers._array_packer
         ),
     ),
     OsefTypes.NUMBER_OF_LAYERS.value: TypeInfo(
-        "number_of_layers",
+        OsefKeys.NUMBER_OF_LAYERS.value,
         LeafInfo(
             _unpackers._get_value_unpacker("<L"), _packers._get_value_packer("<L")
         ),
     ),
-    OsefTypes.CLOUD_PROCESSING.value: TypeInfo(
-        "cloud_processing",
+    OsefTypes._CLOUD_PROCESSING.value: TypeInfo(
+        OsefKeys._CLOUD_PROCESSING.value,
         LeafInfo(
             _unpackers._processing_bitfield_unpacker,
             _packers._processing_bitfield_packer,
         ),
     ),
-    OsefTypes.RANGE_AZIMUTH.value: TypeInfo(
-        "range_azimuth",
+    OsefTypes._RANGE_AZIMUTH.value: TypeInfo(
+        OsefKeys._RANGE_AZIMUTH.value,
         LeafInfo(
             _unpackers._get_dict_unpacker(
                 "<ff", ["azimuth_begin_deg", "azimuth_end_deg"]
@@ -115,8 +121,8 @@ outsight_types = {
             _packers._get_dict_packer("<ff", ["azimuth_begin_deg", "azimuth_end_deg"]),
         ),
     ),
-    OsefTypes.BBOX_ARRAY.value: TypeInfo(
-        "bounding_boxes_array",
+    OsefTypes._BOUNDING_BOXES_ARRAY.value: TypeInfo(
+        OsefKeys._BOUNDING_BOXES_ARRAY.value,
         LeafInfo(
             _unpackers._get_structured_array_unpacker(
                 np.dtype(
@@ -134,36 +140,36 @@ outsight_types = {
         ),
     ),
     OsefTypes.CLASS_ID_ARRAY.value: TypeInfo(
-        "class_id_array",
+        OsefKeys.CLASS_ID_ARRAY.value,
         LeafInfo(_unpackers._class_array_unpacker, _packers._class_array_packer),
     ),
-    OsefTypes.CONFIDENCE_ARRAY.value: TypeInfo(
-        "confidence_array",
+    OsefTypes._CONFIDENCE_ARRAY.value: TypeInfo(
+        OsefKeys._CONFIDENCE_ARRAY.value,
         LeafInfo(
             _unpackers._get_array_unpacker(np.dtype(np.float32)), _packers._array_packer
         ),
     ),
-    OsefTypes.TIMESTAMP_DATA.value: TypeInfo(
-        "timestamped_data", InternalNodeInfo(dict)
+    OsefTypes.TIMESTAMPED_DATA.value: TypeInfo(
+        OsefKeys.TIMESTAMPED_DATA.value, InternalNodeInfo(dict)
     ),
-    OsefTypes.PERCEPT.value: TypeInfo(
-        "percept",
+    OsefTypes._PERCEPT.value: TypeInfo(
+        OsefKeys._PERCEPT.value,
         LeafInfo(_unpackers._percept_class_unpacker, _packers._percept_class_packer),
     ),
-    OsefTypes.CLUSTER.value: TypeInfo(
-        "cluster",
-        LeafInfo(
-            _unpackers._get_array_unpacker(np.dtype(np.uint16)), _packers._array_packer
-        ),
+    OsefTypes._BGR_IMAGE_FRAME.value: TypeInfo(
+        OsefKeys._BGR_IMAGE_FRAME.value, InternalNodeInfo(dict)
     ),
-    OsefTypes.BGR_IMAGE.value: TypeInfo("bgr_image_frame", InternalNodeInfo(dict)),
     OsefTypes.POSE.value: TypeInfo(
-        "pose", LeafInfo(_unpackers._pose_unpacker, _packers._pose_packer)
+        OsefKeys.POSE.value, LeafInfo(_unpackers._pose_unpacker, _packers._pose_packer)
     ),
-    OsefTypes.SCAN_FRAME.value: TypeInfo("scan_frame", InternalNodeInfo(dict)),
-    OsefTypes.TRACKED_OBJECT.value: TypeInfo("tracked_objects", InternalNodeInfo(dict)),
-    OsefTypes.BOUNDING_BOX_SIZE.value: TypeInfo(
-        "bbox_sizes",
+    OsefTypes.SCAN_FRAME.value: TypeInfo(
+        OsefKeys.SCAN_FRAME.value, InternalNodeInfo(dict)
+    ),
+    OsefTypes.TRACKED_OBJECTS.value: TypeInfo(
+        OsefKeys.TRACKED_OBJECTS.value, InternalNodeInfo(dict)
+    ),
+    OsefTypes.BBOX_SIZES.value: TypeInfo(
+        OsefKeys.BBOX_SIZES.value,
         LeafInfo(
             _unpackers._get_structured_array_unpacker(
                 np.dtype(
@@ -179,8 +185,8 @@ outsight_types = {
             _packers._structured_array_packer,
         ),
     ),
-    OsefTypes.SPEED_VECTOR.value: TypeInfo(
-        "speed_vectors",
+    OsefTypes.SPEED_VECTORS.value: TypeInfo(
+        OsefKeys.SPEED_VECTORS.value,
         LeafInfo(
             _unpackers._get_structured_array_unpacker(
                 np.dtype(
@@ -191,18 +197,18 @@ outsight_types = {
         ),
     ),
     OsefTypes.POSE_ARRAY.value: TypeInfo(
-        "pose_array",
+        OsefKeys.POSE_ARRAY.value,
         LeafInfo(_unpackers._pose_array_unpacker, _packers._pose_array_packer),
     ),
     OsefTypes.OBJECT_ID.value: TypeInfo(
-        "object_id",
+        OsefKeys.OBJECT_ID.value,
         LeafInfo(
             _unpackers._get_array_unpacker(np.dtype(np.ulonglong)),
             _packers._array_packer,
         ),
     ),
-    OsefTypes.CARTESIAN_COORD_4F.value: TypeInfo(
-        "cartesian_coordinates_4f",
+    OsefTypes.CARTESIAN_COORDINATES_4F.value: TypeInfo(
+        OsefKeys.CARTESIAN_COORDINATES_4F.value,
         LeafInfo(
             _unpackers._get_structured_array_unpacker(
                 np.dtype(
@@ -221,8 +227,8 @@ outsight_types = {
     ),
     # __todrop are unused columns that are here to
     # have 4 floats in the TLV which is more cpu efficient.
-    OsefTypes.SPHERICAL_COORD_4F.value: TypeInfo(
-        "spherical_coordinates_4f",
+    OsefTypes.SPHERICAL_COORDINATES_4F.value: TypeInfo(
+        OsefKeys.SPHERICAL_COORDINATES_4F.value,
         LeafInfo(
             _unpackers._get_structured_array_unpacker(
                 np.dtype(
@@ -239,10 +245,12 @@ outsight_types = {
             _packers._structured_array_packer,
         ),
     ),
-    OsefTypes.ZONES.value: TypeInfo("zones_def", InternalNodeInfo(list)),
-    OsefTypes.ZONE.value: TypeInfo("zone", InternalNodeInfo(dict)),
-    OsefTypes.ZONE_VERTICE.value: TypeInfo(
-        "zone_vertices",
+    OsefTypes.ZONES_DEF.value: TypeInfo(
+        OsefKeys.ZONES_DEF.value, InternalNodeInfo(list)
+    ),
+    OsefTypes.ZONE.value: TypeInfo(OsefKeys.ZONE.value, InternalNodeInfo(dict)),
+    OsefTypes.ZONE_VERTICES.value: TypeInfo(
+        OsefKeys.ZONE_VERTICES.value,
         LeafInfo(
             _unpackers._get_structured_array_unpacker(
                 np.dtype(([("x", np.float32), ("y", np.float32)])),
@@ -251,14 +259,15 @@ outsight_types = {
         ),
     ),
     OsefTypes.ZONE_NAME.value: TypeInfo(
-        "zone_name",
+        OsefKeys.ZONE_NAME.value,
         LeafInfo(_unpackers._get_string_unpacker(), _packers._get_string_packer()),
     ),
-    OsefTypes.ZONE_UUID.value: TypeInfo(
-        "zone_uuid", LeafInfo(lambda v: uuid.UUID(bytes=v), lambda v: v.bytes)
+    OsefTypes._ZONE_UUID.value: TypeInfo(
+        OsefKeys._ZONE_UUID.value,
+        LeafInfo(lambda v: uuid.UUID(bytes=v), lambda v: v.bytes),
     ),
-    OsefTypes.ZONE_BINDINGS.value: TypeInfo(
-        "zones_objects_binding",
+    OsefTypes.ZONES_OBJECTS_BINDING.value: TypeInfo(
+        OsefKeys.ZONES_OBJECTS_BINDING.value,
         LeafInfo(
             _unpackers._get_structured_array_unpacker(
                 np.dtype(
@@ -269,34 +278,38 @@ outsight_types = {
         ),
     ),
     OsefTypes.OBJECT_PROPERTIES.value: TypeInfo(
-        "object_properties",
+        OsefKeys.OBJECT_PROPERTIES.value,
         LeafInfo(
             _unpackers._object_properties_unpacker, _packers._object_properties_packer
         ),
     ),
-    OsefTypes.IMU_PACKET.value: TypeInfo(
-        "imu_packet", LeafInfo(_unpackers._imu_unpacker, _packers._imu_packer)
+    OsefTypes._IMU_PACKET.value: TypeInfo(
+        OsefKeys._IMU_PACKET.value,
+        LeafInfo(_unpackers._imu_unpacker, _packers._imu_packer),
     ),
-    OsefTypes.VELODYNE_TIMESTAMP.value: TypeInfo(
-        "timestamp_lidar_velodyne",
+    OsefTypes._TIMESTAMP_LIDAR_VELODYNE.value: TypeInfo(
+        OsefKeys._TIMESTAMP_LIDAR_VELODYNE.value,
         LeafInfo(
             _unpackers._get_dict_unpacker("<LL", ["unix_s", "remaining_us"]),
             _packers._get_dict_packer("<LL", ["unix_s", "remaining_us"]),
         ),
     ),
     OsefTypes.POSE_RELATIVE.value: TypeInfo(
-        "pose_relative", LeafInfo(_unpackers._pose_unpacker, _packers._pose_packer)
+        OsefKeys.POSE_RELATIVE.value,
+        LeafInfo(_unpackers._pose_unpacker, _packers._pose_packer),
     ),
-    OsefTypes.GRAVITY.value: TypeInfo(
-        "gravity",
+    OsefTypes._GRAVITY.value: TypeInfo(
+        OsefKeys._GRAVITY.value,
         LeafInfo(
             _unpackers._get_dict_unpacker("<fff", ["x", "y", "z"]),
             _packers._get_dict_packer("<fff", ["x", "y", "z"]),
         ),
     ),
-    OsefTypes.EGO_MOTION.value: TypeInfo("ego_motion", InternalNodeInfo(dict)),
-    OsefTypes.PREDICTED_POSITION.value: TypeInfo(
-        "predicted_position",
+    OsefTypes.EGO_MOTION.value: TypeInfo(
+        OsefKeys.EGO_MOTION.value, InternalNodeInfo(dict)
+    ),
+    OsefTypes._PREDICTED_POSITION.value: TypeInfo(
+        OsefKeys._PREDICTED_POSITION.value,
         LeafInfo(
             _unpackers._get_structured_array_unpacker(
                 np.dtype(
@@ -307,7 +320,7 @@ outsight_types = {
         ),
     ),
     OsefTypes.GEOGRAPHIC_POSE.value: TypeInfo(
-        "geographic_pose",
+        OsefKeys.GEOGRAPHIC_POSE.value,
         LeafInfo(
             _unpackers._get_structured_array_unpacker(
                 np.dtype(
@@ -324,13 +337,13 @@ outsight_types = {
         ),
     ),
     OsefTypes.OBJECT_ID_32_BITS.value: TypeInfo(
-        "object_id_32_bits",
+        OsefKeys.OBJECT_ID_32_BITS.value,
         LeafInfo(
             _unpackers._get_array_unpacker(np.dtype(np.uint32)), _packers._array_packer
         ),
     ),
-    OsefTypes.ZONE_BINDINGS_32_BITS.value: TypeInfo(
-        "zones_objects_binding_32_bits",
+    OsefTypes.ZONES_OBJECTS_BINDING_32_BITS.value: TypeInfo(
+        OsefKeys.ZONES_OBJECTS_BINDING_32_BITS.value,
         LeafInfo(
             _unpackers._get_structured_array_unpacker(
                 np.dtype(
@@ -340,42 +353,42 @@ outsight_types = {
             _packers._structured_array_packer,
         ),
     ),
-    OsefTypes.BACKGROUND_BITS.value: TypeInfo(
-        "background_bits",
+    OsefTypes._BACKGROUND_BITS.value: TypeInfo(
+        OsefKeys._BACKGROUND_BITS.value,
         LeafInfo(_unpackers._bool_bitfield_unpacker, _packers._bool_bitfield_packer),
     ),
-    OsefTypes.GROUND_PLANE_BITS.value: TypeInfo(
-        "ground_plane_bits",
+    OsefTypes._GROUND_PLANE_BITS.value: TypeInfo(
+        OsefKeys._GROUND_PLANE_BITS.value,
         LeafInfo(_unpackers._bool_bitfield_unpacker, _packers._bool_bitfield_packer),
     ),
-    OsefTypes.AZIMUTHS.value: TypeInfo(
-        "azimuths",
+    OsefTypes._AZIMUTHS.value: TypeInfo(
+        OsefKeys._AZIMUTHS.value,
         LeafInfo(
             _unpackers._get_array_unpacker(np.dtype(np.float32)), _packers._array_packer
         ),
     ),
-    OsefTypes.ELEVATIONS.value: TypeInfo(
-        "elevations",
+    OsefTypes._ELEVATIONS.value: TypeInfo(
+        OsefKeys._ELEVATIONS.value,
         LeafInfo(
             _unpackers._get_array_unpacker(np.dtype(np.float32)), _packers._array_packer
         ),
     ),
-    OsefTypes.DISTANCES.value: TypeInfo(
-        "distances",
+    OsefTypes._DISTANCES.value: TypeInfo(
+        OsefKeys._DISTANCES.value,
         LeafInfo(
             _unpackers._get_array_unpacker(np.dtype(np.float32)), _packers._array_packer
         ),
     ),
-    OsefTypes.LIDAR_MODEL.value: TypeInfo(
-        "lidar_model",
+    OsefTypes._LIDAR_MODEL.value: TypeInfo(
+        OsefKeys._LIDAR_MODEL.value,
         LeafInfo(_unpackers._lidar_model_unpacker, _packers._lidar_model_packer),
     ),
     OsefTypes.SLAM_POSE_ARRAY.value: TypeInfo(
-        "slam_pose_array",
+        OsefKeys.SLAM_POSE_ARRAY.value,
         LeafInfo(_unpackers._pose_array_unpacker, _packers._pose_array_packer),
     ),
     OsefTypes.ZONE_VERTICAL_LIMITS.value: TypeInfo(
-        "zone_vertical_limits",
+        OsefKeys.ZONE_VERTICAL_LIMITS.value,
         LeafInfo(
             _unpackers._get_array_unpacker(
                 np.dtype(np.float32),
@@ -384,7 +397,7 @@ outsight_types = {
         ),
     ),
     OsefTypes.GEOGRAPHIC_POSE_PRECISE.value: TypeInfo(
-        "geographic_pose_precise",
+        OsefKeys.GEOGRAPHIC_POSE_PRECISE.value,
         LeafInfo(
             _unpackers._get_structured_array_unpacker(
                 np.dtype(
@@ -400,10 +413,14 @@ outsight_types = {
             _packers._structured_array_packer,
         ),
     ),
-    OsefTypes.ROAD_MARKINGS_BITS.value: TypeInfo(
-        "road_markings_bits",
+    OsefTypes._ROAD_MARKINGS_BITS.value: TypeInfo(
+        OsefKeys._ROAD_MARKINGS_BITS.value,
         LeafInfo(_unpackers._bool_bitfield_unpacker, _packers._bool_bitfield_packer),
     ),
+    OsefTypes.FILTERED_POSE.value: TypeInfo(
+        OsefKeys.FILTERED_POSE.value,
+        LeafInfo(_unpackers._pose_array_unpacker, _packers._pose_array_packer),
+    ),
 }
 
 
